bibliotheca Augustana

<<< Einführung
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge nôt ## Handschrift B ## um 1250 ## St. Galler Handschrift ## nach der digitalen Edition ## von Hermann Reichert
___________________________________________________
###### 1 | keine Überschrift [C: Aventivre von den Nibelungen]
###### 2 | k. Ü. [A: Aventivre von Sifride]
###### 3 | k. Ü. [A: Wie si ze Wormz chomen]
###### 4 | k. Ü. [A: Wie er mit den Sahsen stareit]
###### 5 | k. Ü. [A: Wie Sifrit Krimhilt erst gesach]
###### 6 | k. Ü. [A: Wie Gvnther gen Isenlande nach Prvnhilt fvor]
###### 7 | k. Ü. [A: Wie Gvnther Prvnhilde gewan]
###### 8 | k. Ü. [A: Wie Sifrit nach den Nibelvngen fvr]
###### 9 | k. Ü. [A: Wie Sifrit ze Wormz gesant wart]
###### 10 | k. Ü. [A: Wie Prvnhilt ze Wormz enphangen wart]
###### 11 | k. Ü. [A: Wie Sifrit ze lande mit sinem wibe kom]
###### 12 | k. Ü. [A: Wie Gvnther Sifriden zvo der hohzit bat]
###### 13 | k. Ü. [A: Wie si ze der hohzit fvrn]
###### 14 | k. Ü. [A: Wie die chvniginnen an ander schvlten]
###### 15 | k. Ü. [A: Wie Sifrit verraten wart]
###### 16 | k. Ü. [A: Wie Sifrit erslagen wart]
###### 17 | k. Ü. [A: Wie Sifrit bechlaget vñ begraben wart]
###### 18 | k. Ü. [A: Wie Sigmvnt wider ze lande fvr]
###### 19 | k. Ü. [A: Wie der Niblvnge hort ze Wormz chom]
###### 20 | k. Ü. [A: Wie chvnk Ezel ze Bvrgonden nach Krimhilt sande]
###### 21 | k. Ü. [A: Aventivr wie si hin fvr]
###### 22 | k. Ü. [A: Wie si zen Hvnen wart enphangen]
###### 23 | k. Ü. [A: Wie Krimhilt ir leit gedaht ze rechen]
###### 24 | k. Ü. [A: Wie Werbel vñ Svemel die botschaft wrben]
###### 25 | k. Ü. [A: Wie die herren alle zen Hevnen fvren]
###### 26 | k. Ü. [A: Wie Danchwart Gelffraten slvch]
###### 27 | k. Ü. [C: Auentv wie der marchrave die kunige mit ir rechen in sin hvs enpfie vñ wier ir sit pflach]
###### 28 | k. Ü. [A: Wie Chrimhilt Hagen enphie]
###### 29 | k. Ü. [A: Wie gen if vf stvont]
###### 30 | k. Ü. [A: Wie si der schiltwaht phlagen]
###### 31 | k. Ü. [A: Wie si ze chirchen giengen]
###### 32 | k. Ü. [A: Wie Bloedelin erslagen wart]
###### 33 | k. Ü. [A: Wie die Bvrgonden mit den Hevnen striten]
###### 34 | k. Ü. [A: Wie si toten abe wurfen]
###### 35 | k. Ü. [A: Wie Irinch erslagen wart]
###### 36 | k. Ü. [A: Aventivr wie div chvnigin den sal beraiten hiez]
###### 37 | k. Ü. [A: Aventivr wie der marchgrave Rvodeger erslagen wart]
###### 38 | k. Ü. [A: Wie hern Dietriches man alle erslagen wrden]
###### 39 | k. Ü. [A: Av wie Gvnther vñ Chrimh' vñ Hagen wurden erslagen]
## Codex Sang. 857, Strophen 1 - 22.2 ## Codex Sang. 857, Strophen 2014 - 2030

<<< Einführung